import sqlite3

class Database:
    def __init__(self, db_name):
        self.db_name = db_name
        self.connection = None
        self.cursor = None

    def connect(self):
        self.connection = sqlite3.connect(self.db_name)
        self.cursor = self.connection.cursor()

    def disconnect(self):
        if self.connection:
            self.connection.commit()
            self.connection.close()

    def create_table(self, table_name, columns):
        self.connect()
        column_str = ', '.join(columns)
        create_table_query = f'CREATE TABLE IF NOT EXISTS {table_name} ({column_str})'
        self.cursor.execute(create_table_query)

    def insert_data(self, table_name, values):
        self.connect()
        value_placeholders = ', '.join(['?'] * len(values))
        insert_query = f'INSERT INTO {table_name} VALUES ({value_placeholders})'
        self.cursor.execute(insert_query, values)

    def select_all_data(self, table_name):
        self.connect()
        select_query = f'SELECT * FROM {table_name}'
        self.cursor.execute(select_query)
        rows = self.cursor.fetchall()
        return rows

    def select_data(self, data_name, table_name):
        self.connect()
        data_name = ", ".join(data_name)
        select_query = f'SELECT {data_name} FROM {table_name}'
        self.cursor.fetchall(select_data)