from PIL import Image
import numpy as np
import cv2
import os
from tqdm import tqdm
import random as rd
from colorama import Fore, Style

def load_images(image_path):
    return np.array(Image.open(image_path))

def gray_image(images, path=None, name=None, array=False):
    gray_list = []
    num = 0
    array_list = []
    for image in tqdm(images, desc='Processing', unit='image'):
        image_cv2 = np.array(image)
        gray_image_cv2 = cv2.cvtColor(image_cv2, cv2.COLOR_BGR2GRAY)
        if path is not None or name is not None:
            name = f"{name}_{num}.jpg"
            if path is not None:
                name = os.path.join(path, name)
            cv2.imwrite(name, gray_image_cv2)
            num += 1
        if array:
            array_list.append(np.array(gray_image_cv2))
    return array_list

def new_data_image(images, array=False, path=None, name=None, resize=None):
    data_image_list = []
    for image in tqdm(images, desc='Processing', unit='image'):
        data_images = []
        image = np.array(image)
        data_images.append(cv2.rotate(image, cv2.ROTATE_90_COUNTERCLOCKWISE))
        data_images.append(cv2.rotate(image, cv2.ROTATE_180))
        data_images.append(cv2.rotate(image, cv2.ROTATE_90_CLOCKWISE))

        num = 0  
        if name is not None and path is not None:
                
            for i in data_images:
                file_name = f"{name}_{num}.jpg"
                cv2.imwrite(os.path.join(path, file_name), i)
                num += 1

        elif name is not None:
                
            for i in tqdm(data_images):
                file_name = f"{name}_{num}.jpg"
                cv2.imwrite(file_name, i)
                num += 1

        data_image_list.extend(data_images)

        if resize is not None:
            resized_data_images = [cv2.resize(img, resize) for img in data_images]
            data_image_list.extend(resized_data_images)
    return data_image_list

def use_PIL(image):
    return Image.fromarray(image)




def show(name, image):
    try:
        img = cv2.imread(image)
        cv2.imshow(name, img)
    except TypeError:
        cv2.imshow(name, image)
    print(f"{Fore.LIGHTGREEN_EX}Image opened successfully{Style.RESET_ALL}")
    while True:
        if cv2.waitKey(1) & 0xFF == ord("q"):
            break
    # ปิดหน้าต่าง
    cv2.destroyAllWindows()
    print(f"{Fore.LIGHTGREEN_EX}closed image successfully{Style.RESET_ALL}")
    return

def adjust_img_color(image, number_new=1, color_value=0, color_value_end=1):
    list_img = []
    for _ in tqdm(range(number_new+1), desc='Processing', unit='image'):
        list_img.append(cv2.convertScaleAbs(image, alpha=rd.uniform(color_value, color_value_end)))
    return list_img